# anemoi-graphs

<p align="center">
  <a href="https://github.com/ecmwf/codex/raw/refs/heads/main/Project Maturity">
    <img src="https://github.com/ecmwf/codex/raw/refs/heads/main/Project Maturity/incubating_badge.svg" alt="Maturity Level">
  </a>
  <a href="https://opensource.org/licenses/apache-2-0">
    <img src="https://img.shields.io/badge/Licence-Apache 2.0-blue.svg" alt="Licence">
  </a>
  <!-- Individual package releases -->
  <a href="https://github.com/ecmwf/anemoi-graphs/releases">
    <img src="https://img.shields.io/github/v/release/ecmwf/anemoi-graphs?color=orange&label=Graphs%20Release" alt="Anemoi Graphs Release">
  </a>
  <!-- documentation badges -->
  <a href="https://anemoi-graphs.readthedocs.io/en/latest/">
    <img src="https://img.shields.io/readthedocs/anemoi-graphs/latest?label=Docs%20(Graphs)&color=green" alt="Anemoi Graphs Docs">
  </a>
</p>

> \[!IMPORTANT\]
> This software is **Incubating** and subject to ECMWF's guidelines on [Software Maturity](https://github.com/ecmwf/codex/raw/refs/heads/main/Project%20Maturity).

A package to build graphs for data-driven forecasts.

## Documentation

The documentation can be found at https://anemoi-graphs.readthedocs.io/.

## Install

Install via `pip` with:

```
$ pip install anemoi-graphs
```

## Usage

Create your graph using the configuration given in the config file. The resulting graph will be saved in the given path.

```
$ anemoi-graphs create recipe.yaml my_graph.pt
```

## License

```
Copyright 2024, Anemoi contributors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

In applying this licence, ECMWF does not waive the privileges and immunities
granted to it by virtue of its status as an intergovernmental organisation
nor does it submit to any jurisdiction.
```
